input: atmel_maxtouch: Rename mxt_platform_data to maxtouch_platform_data

Opensource driver atmel_mxt_ts has the platform data
structure name as atmel_maxtouch. Avoid name conflict
by renaming atmel_maxtouch driver's platform data to
maxtouch_platform_data.

Change-Id: I4bf3ed83e3eab55c4464de365c6009965da73744
Signed-off-by: Mohan Pallaka <mpallaka@codeaurora.org>
diff --git a/arch/arm/mach-msm/board-msm7x27a.c b/arch/arm/mach-msm/board-msm7x27a.c
index aada890..05b4896 100644
--- a/arch/arm/mach-msm/board-msm7x27a.c
+++ b/arch/arm/mach-msm/board-msm7x27a.c
@@ -3041,7 +3041,7 @@
 #define ATMEL_X_OFFSET 13
 #define ATMEL_Y_OFFSET 0
 
-static struct mxt_platform_data atmel_ts_pdata = {
+static struct maxtouch_platform_data atmel_ts_pdata = {
 	.numtouch = 4,
 	.init_platform_hw = atmel_ts_platform_init,
 	.exit_platform_hw = atmel_ts_platform_exit,
diff --git a/drivers/input/touchscreen/atmel_maxtouch.c b/drivers/input/touchscreen/atmel_maxtouch.c
index 35507e1..e397774 100644
--- a/drivers/input/touchscreen/atmel_maxtouch.c
+++ b/drivers/input/touchscreen/atmel_maxtouch.c
@@ -1878,7 +1878,7 @@
 			       const struct i2c_device_id *id)
 {
 	struct mxt_data          *mxt;
-	struct mxt_platform_data *pdata;
+	struct maxtouch_platform_data *pdata;
 	struct input_dev         *input;
 	u8 *id_data;
 	u8 *t38_data;
diff --git a/include/linux/atmel_maxtouch.h b/include/linux/atmel_maxtouch.h
index c582529..012e68b 100644
--- a/include/linux/atmel_maxtouch.h
+++ b/include/linux/atmel_maxtouch.h
@@ -283,7 +283,7 @@
 #endif
 
 /**
  * struct mxt_platform_data - includes platform specific informatio
  * related to Atmel maXTouch touchscreen controller.
  * 
  * @numtouch:           Number of simultaneous touches supported
@@ -298,7 +298,7 @@
  * @max_y:              Reported Y range
  */
  
-struct mxt_platform_data {
+struct maxtouch_platform_data {
 	u8    numtouch;	/* Number of touches to report	*/
 	int   (*init_platform_hw)(struct i2c_client *client);
 	int   (*exit_platform_hw)(struct i2c_client *client);
@@ -283,7 +283,7 @@
 
 /**
- * struct mxt_platform_data - includes platform specific informatio
+ * struct maxtouch_platform_data - includes platform specific informatio
  * related to Atmel maXTouch touchscreen controller.
  * 